==> aws-cdk-scala_2.12-0.12.0-sources.jar: io/burkard/cdk/services/appflow/cfnFlow/SourceConnectorPropertiesProperty.scala <==
package io.burkard.cdk.services.appflow.cfnFlow

@SuppressWarnings(Array("org.wartremover.warts.DefaultArguments", "org.wartremover.warts.Null", "DisableSyntax.null"))
object SourceConnectorPropertiesProperty {

  def apply(
    amplitude: Option[software.amazon.awscdk.services.appflow.CfnFlow.AmplitudeSourcePropertiesProperty] = None,
    s3: Option[software.amazon.awscdk.services.appflow.CfnFlow.S3SourcePropertiesProperty] = None,
    serviceNow: Option[software.amazon.awscdk.services.appflow.CfnFlow.ServiceNowSourcePropertiesProperty] = None,
    zendesk: Option[software.amazon.awscdk.services.appflow.CfnFlow.ZendeskSourcePropertiesProperty] = None,
    singular: Option[software.amazon.awscdk.services.appflow.CfnFlow.SingularSourcePropertiesProperty] = None,
    datadog: Option[software.amazon.awscdk.services.appflow.CfnFlow.DatadogSourcePropertiesProperty] = None,
    trendmicro: Option[software.amazon.awscdk.services.appflow.CfnFlow.TrendmicroSourcePropertiesProperty] = None,
    sapoData: Option[software.amazon.awscdk.services.appflow.CfnFlow.SAPODataSourcePropertiesProperty] = None,
    slack: Option[software.amazon.awscdk.services.appflow.CfnFlow.SlackSourcePropertiesProperty] = None,
    googleAnalytics: Option[software.amazon.awscdk.services.appflow.CfnFlow.GoogleAnalyticsSourcePropertiesProperty] = None,
    marketo: Option[software.amazon.awscdk.services.appflow.CfnFlow.MarketoSourcePropertiesProperty] = None,
    veeva: Option[software.amazon.awscdk.services.appflow.CfnFlow.VeevaSourcePropertiesProperty] = None,
    dynatrace: Option[software.amazon.awscdk.services.appflow.CfnFlow.DynatraceSourcePropertiesProperty] = None,
    inforNexus: Option[software.amazon.awscdk.services.appflow.CfnFlow.InforNexusSourcePropertiesProperty] = None,
    salesforce: Option[software.amazon.awscdk.services.appflow.CfnFlow.SalesforceSourcePropertiesProperty] = None
  ): software.amazon.awscdk.services.appflow.CfnFlow.SourceConnectorPropertiesProperty =
    (new software.amazon.awscdk.services.appflow.CfnFlow.SourceConnectorPropertiesProperty.Builder)
      .amplitude(amplitude.orNull)
      .s3(s3.orNull)
      .serviceNow(serviceNow.orNull)
      .zendesk(zendesk.orNull)
      .singular(singular.orNull)
      .datadog(datadog.orNull)
      .trendmicro(trendmicro.orNull)
      .sapoData(sapoData.orNull)
      .slack(slack.orNull)
      .googleAnalytics(googleAnalytics.orNull)
      .marketo(marketo.orNull)
      .veeva(veeva.orNull)
      .dynatrace(dynatrace.orNull)
      .inforNexus(inforNexus.orNull)
      .salesforce(salesforce.orNull)
      .build()
}

==> aws-cdk-scala_2.13-0.22.0-sources.jar: io/burkard/cdk/services/appflow/cfnFlow/SourceConnectorPropertiesProperty.scala <==
package io.burkard.cdk.services.appflow.cfnFlow

@SuppressWarnings(Array("org.wartremover.warts.DefaultArguments", "org.wartremover.warts.Null", "DisableSyntax.null"))
object SourceConnectorPropertiesProperty {

  def apply(
    amplitude: Option[software.amazon.awscdk.services.appflow.CfnFlow.AmplitudeSourcePropertiesProperty] = None,
    s3: Option[software.amazon.awscdk.services.appflow.CfnFlow.S3SourcePropertiesProperty] = None,
    customConnector: Option[software.amazon.awscdk.services.appflow.CfnFlow.CustomConnectorSourcePropertiesProperty] = None,
    serviceNow: Option[software.amazon.awscdk.services.appflow.CfnFlow.ServiceNowSourcePropertiesProperty] = None,
    zendesk: Option[software.amazon.awscdk.services.appflow.CfnFlow.ZendeskSourcePropertiesProperty] = None,
    singular: Option[software.amazon.awscdk.services.appflow.CfnFlow.SingularSourcePropertiesProperty] = None,
    datadog: Option[software.amazon.awscdk.services.appflow.CfnFlow.DatadogSourcePropertiesProperty] = None,
    trendmicro: Option[software.amazon.awscdk.services.appflow.CfnFlow.TrendmicroSourcePropertiesProperty] = None,
    sapoData: Option[software.amazon.awscdk.services.appflow.CfnFlow.SAPODataSourcePropertiesProperty] = None,
    slack: Option[software.amazon.awscdk.services.appflow.CfnFlow.SlackSourcePropertiesProperty] = None,
    googleAnalytics: Option[software.amazon.awscdk.services.appflow.CfnFlow.GoogleAnalyticsSourcePropertiesProperty] = None,
    marketo: Option[software.amazon.awscdk.services.appflow.CfnFlow.MarketoSourcePropertiesProperty] = None,
    veeva: Option[software.amazon.awscdk.services.appflow.CfnFlow.VeevaSourcePropertiesProperty] = None,
    dynatrace: Option[software.amazon.awscdk.services.appflow.CfnFlow.DynatraceSourcePropertiesProperty] = None,
    inforNexus: Option[software.amazon.awscdk.services.appflow.CfnFlow.InforNexusSourcePropertiesProperty] = None,
    salesforce: Option[software.amazon.awscdk.services.appflow.CfnFlow.SalesforceSourcePropertiesProperty] = None
  ): software.amazon.awscdk.services.appflow.CfnFlow.SourceConnectorPropertiesProperty =
    (new software.amazon.awscdk.services.appflow.CfnFlow.SourceConnectorPropertiesProperty.Builder)
      .amplitude(amplitude.orNull)
      .s3(s3.orNull)
      .customConnector(customConnector.orNull)
      .serviceNow(serviceNow.orNull)
      .zendesk(zendesk.orNull)
      .singular(singular.orNull)
      .datadog(datadog.orNull)
      .trendmicro(trendmicro.orNull)
      .sapoData(sapoData.orNull)
      .slack(slack.orNull)
      .googleAnalytics(googleAnalytics.orNull)
      .marketo(marketo.orNull)
      .veeva(veeva.orNull)
      .dynatrace(dynatrace.orNull)
      .inforNexus(inforNexus.orNull)
      .salesforce(salesforce.orNull)
      .build()
}
